# A custom extension for simple 3d graphs

This example shows how Bokeh custom extension models can be used with Bokeh server applications. While there are many great features built into Bokeh, with custom extensions, and the Bokeh server, it becomes simple to connect powerful Python tools for data analytics to almost any web tool, widget, or framework, even if it is not built into Bokeh natively.

This example demonstrates connecting a Bokeh `ColumnDataSource` to the VisJS Graph3d library. The 3d plot below is being continuously updated by periodic callbacks in a Bokeh server application. You can pan to rotate the figure, scroll or pinch to zoom.